@@ -31,7 +31,7 @@ class OutputFormat:
     )
 
 
-class PropertiesColumn(FormattableColumn):
+class YamlColumn(FormattableColumn):
     def human_readable(self):
         return yaml.dump(self._value)
 
@@ -39,7 +39,12 @@ class PropertiesColumn(FormattableColumn):
 class HardwareSerializer(object):
     def serialize_hardware(self, hw_dict: "dict", columns: "list[str]"):
         return utils.get_dict_properties(
-            hw_dict, columns, formatters={"properties": PropertiesColumn}
+            hw_dict,
+            columns,
+            formatters={
+                "properties": YamlColumn,
+                "workers": YamlColumn,
+            },
         )
 
 
@@ -93,7 +98,7 @@ class GetHardware(BaseParser, command.ShowOne, HardwareSerializer):
     """List specific hardware item in Doni."""
 
     require_hardware = True
-    columns = OutputFormat.columns
+    columns = (*OutputFormat.columns, "workers")
 
     def take_action(self, parsed_args):
         """List all hw items in Doni."""
